<?php

namespace Drupal\monarch_auth_homepage\Path;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Path\PathMatcher as CorePathMatcher;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;

/**
 * Provides a path matcher.
 */
class PathMatcher extends CorePathMatcher {

  /**
   * The current_user.
   */
  protected AccountInterface $account;

  /**
   * The config.
   */
  protected ImmutableConfig $config;

  /**
   * Creates a new PathMatcher.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The current route match.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RouteMatchInterface $route_match, AccountInterface $account) {
    $this->configFactory = $config_factory;
    $this->routeMatch = $route_match;
    $this->account = $account;
    $this->config = $config_factory->get('system.site');
  }

  /**
   * {@inheritdoc}
   */
  public function isFrontPage() {
    // Cache the result as this is called often.
    $this->isCurrentFrontPage = FALSE;
    // Ensure that the code can also be executed when there is no active
    // route match, like on exception responses.
    if ($this->routeMatch->getRouteName()) {
      $url = Url::fromRouteMatch($this->routeMatch);
      $this->isCurrentFrontPage = ($url->getRouteName() && '/' . $url->getInternalPath() === $this->getFrontPagePath());
    }

    return $this->isCurrentFrontPage;
  }

  /**
   * Gets the current front page path.
   *
   * @return string
   *   The front page path.
   */
  protected function getFrontPagePath() {
    if ($this->account->hasPermission('use admin home page') && $this->config->get('page.front_admin')) {
      $this->frontPage = $this->config->get('page.front_admin');
    }
    elseif ($this->account->isAuthenticated() && $this->config->get('page.front_auth')) {
      $this->frontPage = $this->config->get('page.front_auth');
    }
    else {
      $this->frontPage = $this->config->get('page.front');
    }

    return $this->frontPage;
  }

}
