<?php

namespace Drupal\monarch_auth_homepage\PathProcessor;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Path processor to replace 'node' with 'content' in URLs.
 *
 * @DCG In case you need to implement only one processor (inbound or outbound)
 * remove the corresponding interface, method and service tag.
 */
final class PathProcessor implements InboundPathProcessorInterface {

  /**
   * Constructs a PathProcessor object.
   */
  public function __construct(
    private readonly ConfigFactoryInterface $config,
    private readonly AccountInterface $account,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request): string {
    if ($path === '/') {
      if ($this->account->hasPermission('use admin home page') && $this->config->get('system.site')->get('page.front_admin')) {
        $path = $this->config->get('system.site')->get('page.front_admin');
      }
      elseif ($this->account->isAuthenticated() && $this->config->get('system.site')->get('page.front_auth')) {
        $path = $this->config->get('system.site')->get('page.front_auth');
      }
      else {
        return $path;
      }

      if (empty($path)) {
        // We have to return a valid path but / does not have a route and config
        // might be broken so stop execution.
        throw new NotFoundHttpException();
      }
      $components = parse_url($path);
      // Remove query string and fragment.
      $path = $components['path'];
      // Merge query parameters from front page configuration value
      // with URL query, so that actual URL takes precedence.
      if (!empty($components['query'])) {
        parse_str($components['query'], $parameters);
        array_replace($parameters, $request->query->all());
        $request->query->replace($parameters);
      }
    }

    return $path;
  }

}
