<?php

namespace Drupal\monarch_auth_homepage\Routing;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\Routing\RouteProvider as CoreRouteProvider;
use Drupal\Core\State\StateInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Database\Connection;
use Drupal\Core\Session\AccountInterface;

/**
 * Override the core route provider.
 *
 * We add extra cache contexts to route collections so we can use path
 * processors to provide different routes for anonymous vs authenticated users.
 */
class RouteProvider extends CoreRouteProvider {

  /**
   * The current user.
   */
  protected AccountInterface $account;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $connection, StateInterface $state, CurrentPathStack $current_path, CacheBackendInterface $cache_backend, InboundPathProcessorInterface $path_processor, CacheTagsInvalidatorInterface $cache_tag_invalidator, $table = 'router', ?LanguageManagerInterface $language_manager = NULL, ?AccountInterface $account = NULL) {
    $this->account = $account;
    parent::__construct($connection, $state, $current_path, $cache_backend, $path_processor, $cache_tag_invalidator, $table, $language_manager);
  }

  /**
   * {@inheritdoc}
   */
  protected function getRouteCollectionCacheId(Request $request) {
    if ($this->account->hasPermission('use admin home page')) {
      $this->addExtraCacheKeyPart('utype', 'admin');
    }
    elseif ($this->account->isAuthenticated()) {
      $this->addExtraCacheKeyPart('utype', 'auth');
    }
    else {
      $this->addExtraCacheKeyPart('utype', 'anon');
    }

    return parent::getRouteCollectionCacheId($request);
  }

}
